@@ -19,14 +19,30 @@ SectTypes = dict(
 def isSectType(item, kind=None):
     """
     Utility to checks if a given item is a Sect type object
+
+    Parameters
+    ----------
+    item : object, list
+        Object to test, or list of objects
+    kind : str, default=None
+        Type of mlky object to test for, ie: ["dict", "list", "var"]
+        None will check if the object is of any mlky type
     """
     if kind is None:
         kind = list(SectTypes)
 
     if isinstance(kind, list):
-        return any([SectTypes[k](item) for k in kind])
+        for k in kind:
+            if isinstance(k, type):
+                k = k.__name__
+            if SectTypes[str(k)](item):
+                return True
+        return False
 
-    return SectTypes[kind](item)
+    if isinstance(kind, type):
+        kind = kind.__name__
+
+    return SectTypes[str(kind)](item)
 
 
 class BaseSect:
@@ -49,8 +65,11 @@ class BaseSect:
     _dtype    = ''    # Data type for this object
     _override = None  # CLI override data
 
+    # DictSect flags
+    _patch = None
+
     # ListSect flags
-    _patchAppend    = False
+    _patchAppend = False
 
     # Var flags
     _coerce         = True
@@ -59,6 +78,9 @@ class BaseSect:
     _convertSlashes = True
     _nullsEqMissing = False
 
+    # Utilities
+    isSectType = staticmethod(isSectType)
+
 
     def __init__(self, _data, key='', parent=None, **kwargs):
         """
@@ -148,6 +170,11 @@ class BaseSect:
         return new
 
 
+    def __delattr__(self, key):
+        if key in self:
+            del self._data[key]
+
+
     def __delitem__(self, key):
         if key in self:
             del self._data[key]
@@ -784,6 +811,10 @@ class BaseSect:
                     Short will condense the items to a single line between [] brackets.
                     Short only works if all items of the list are Var types (not lists
                     or dicts)
+            Var:
+                interp : bool, default=True
+                    Allow interpolation of values. Setting to False will allow
+                    interpolation strings to be printed
         """
         # Determine if to convert this obj to YAML depending on the tags
         if tags:
@@ -796,12 +827,14 @@ class BaseSect:
 
         # Convert self to YAML
         offset = 2
+        desc   = ''
         if isSectType(self._parent, 'list'):
             line = '- '
         elif isSectType(self._parent, 'dict'):
             line = f'{self._key}:'
         elif header:
             line = 'generated:'
+            desc = 'Generated via mlky toYaml'
         else:
             line = ''
             offset = 0
@@ -812,7 +845,7 @@ class BaseSect:
 
         flag  = '*' if defs.get('required') else ' '
         dtype = self._dtype
-        sdesc = defs.get('sdesc', '')
+        sdesc = defs.get('sdesc', desc)
         if line:
             line = [line, flag, dtype, sdesc]
 
@@ -834,7 +867,7 @@ class BaseSect:
             child[0] = ' '*offset + child[0]
 
         # No children were provided, set as an empty object
-        if not lines:
+        if not lines and line:
             line[0] += f' {self._data}'
 
         # Insert this line before the children after formatting
@@ -980,3 +1013,26 @@ class BaseSect:
             return not bool(errors.reduce())
 
         return errors
+
+
+    def isinstance(self, obj=Null, types=None):
+        """
+        Modified isinstance that works on Sect objects. If the input is a str,
+        retrieves that child key from this Sect
+
+        Parameters
+        ----------
+        obj : any
+            Object to check
+        types : type, list[type]
+            Types to check
+        """
+        if isinstance(obj, str):
+            obj = self[obj]
+        elif obj is Null:
+            obj = self
+
+        if hasattr(obj, '_data'):
+            obj = obj._data
+
+        return isinstance(obj, types)
